@@ -1,5 +1,7 @@
 from .atmosphere import AtmosphericMeshEntry, AtmosphericModelEntry
-from .base import ModelEntry
+from .base import ModelEntry, ModelVerbosity
 from .hydrology import HydrologicalModelEntry, NationalWaterModelEntry
+from .ice import IceMeshEntry
 from .ocean import ADCIRCEntry, OceanModelEntry, SCHISMEntry
-from .waves import SWANEntry, WaveMeshEntry, WaveModelEntry, WaveWatch3Entry
+from .waves import SWANEntry, WaveMeshEntry, WaveModelEntry, \
+    WaveWatch3Entry
